#
# spec file for package SDL2_image
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           SDL2_image
%define lname	libSDL2_image-2_0-0
Version:        2.0.5
Release:        1.60
Summary:        Simple DirectMedia Layer 2 image loading library
License:        Zlib
Group:          Development/Libraries/X11
URL:            https://libsdl.org/projects/SDL_image/

#Hg-Clone:	http://hg.libsdl.org/SDL_image/
Source:         https://libsdl.org/projects/SDL_image/release/%name-%version.tar.gz
Source2:        baselibs.conf
Patch1:         CVE-2019-13616.patch
BuildRequires:  dos2unix
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(sdl2) >= 2.0.8

%description
This is a simple library to load images of various formats as SDL
surfaces. This library supports the BMP, PPM, PCX, GIF, JPEG, PNG,
TIFF and WEBP formats.

%package -n %lname
Summary:        Simple DirectMedia Layer 2 image loading library
Group:          System/Libraries
Provides:       SDL2_image = %version-%release

%description -n %lname
This is a simple library to load images of various formats as SDL
surfaces. This library supports the BMP, PPM, PCX, GIF, JPEG, PNG,
TIFF and WEBP formats.

%package -n libSDL2_image-devel
Summary:        Development files for the SDL2 image loader library
Group:          Development/Libraries/X11
Requires:       %lname = %version
Provides:       SDL2_image-devel = %version-%release

%description -n libSDL2_image-devel
This is a simple library to load images of various formats as SDL
surfaces. This library supports the BMP, PPM, PCX, GIF, JPEG, PNG,
TIFF and WEBP formats.

%prep
%autosetup -p1
dos2unix *.txt
rm -rf external

%build
%configure --disable-png-shared --disable-jpg-shared --disable-tif-shared \
	--disable-webp-shared --disable-static
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING.txt
%_libdir/libSDL2_image-2*.so.*

%files -n libSDL2_image-devel
%doc CHANGES.txt README.txt
%_includedir/SDL2/
%_libdir/libSDL2_image.so
%_libdir/pkgconfig/SDL2_image.pc

%changelog
* Fri Aug 23 2019 mgorse@suse.com
- Add CVE-2019-13616.patch: fix heap buffer overflow when reading
  a crafted bmp file (boo#1141844 CVE-2019-13616).
* Fri Aug 23 2019 jengelh@inai.de
- Update to new upstream release 2.0.5
  * Fixed TALOS-2019-0820 CVE-2019-5051
  * Fixed TALOS-2019-0821 CVE-2019-5052
  * Fixed TALOS-2019-0841 CVE-2019-5057 boo#1143763
  * Fixed TALOS-2019-0842 CVE-2019-5058 boo#1143764
  * Fixed TALOS-2019-0843 CVE-2019-5059 boo#1143766
  * Fixed TALOS-2019-0844 CVE-2019-5060 boo#1143768
- Not mentioned by upstream, but issues seemingly further fixed:
  * Fixed CVE-2019-12218 boo#1135789
  * Fixed CVE-2019-12217 boo#1135787
  * Fixed CVE-2019-12220 boo#1135806
  * Fixed CVE-2019-12221 boo#1135796
  * Fixed CVE-2019-12222 boo#1136101
* Wed Nov  7 2018 jengelh@inai.de
- Update to new upstream release 2.0.4
  * Fixed memory issues in the XCF loader:
  * CVE-2018-3839 boo#1089087 TALOS-2018-0521
  * CVE-2018-3977 boo#1114519 TALOS-2018-0645
* Thu Mar  8 2018 jengelh@inai.de
- Update to new upstream release 2.0.3
  * Fixed a number of security issues:
  * TALOS-2017-0488/CVE-2017-12122/boo#1084256:
    IMG_LoadLBM_RW code execution vulnerability
  * TALOS-2017-0489/CVE-2017-14440/boo#1084257:
    ILBM CMAP parsing code execution vulnerability
  * TALOS-2017-0490/CVE-2017-14441/boo#1084282:
    ICO pitch handling code execution vulnerability
  * TALOS-2017-0491/CVE-2017-14442/boo#1084304:
    Image palette population code execution vulnerability
  * TALOS-2017-0497/CVE-2017-14448/boo#1084303:
    load_xcf_tile_rle decompression code execution
  * TALOS-2017-0498/CVE-2017-14449/boo#1084297:
    do_layer_surface double free vulnerability
  * TALOS-2017-0499/CVE-2017-14450/boo#1084288:
    LWZ decompression buffer overflow vulnerability
* Tue Feb 13 2018 jengelh@inai.de
- Update BuildRequires
* Fri Feb  9 2018 jengelh@inai.de
- Update to new upstream release 2.0.2
  * Added simple SVG image support based on Nano SVG
  * Fixed security vulnerability in XCF image loader
    [boo#1062777, CVE-2017-2887]
  * Added optional support for loading images using Windows
    Imaging Component
  * Added libpng save support for much smaller 8-bit images
  * Added JPG save support: IMG_SaveJPG() and IMG_SaveJPG_RW()
* Sun Jan 10 2016 mailaender@opensuse.org
- Update to version 2.0.1
  * Fixed support for transparency in XPM files
  * Fixed memory leak in webp image loading
  * Fixed loading BMP files with large BITMAPINFOHEADER structures
  * Fixed building with libpng 1.4
- Removed bigendian_undefined_s.patch
* Thu Jan  8 2015 jengelh@inai.de
- Improve package summary and description. Drop --with-pic which
  is enabled implicitly anyway, remove redundant Requires.
* Thu Sep 12 2013 dvaleev@suse.com
- Fix undefined s on BigEndian platforms (bigendian_undefined_s.patch)
* Tue Aug 13 2013 jengelh@inai.de
- Some metadata spruce-up: add current URLs, softer wildcarding
  in the files list, more robust make install call
* Tue Aug 13 2013 prusnak@opensuse.org
- created package (version 2.0.0) - based on SDL_image package
